/**
 * $Id: Synchronized.java,v 1.1 2009/03/24 08:38:26 oboehm Exp $
 *
 * Copyright (c) 2008 by Oliver Boehm
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express orimplied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 * (c)reated 13.11.2008 by oliver (ob@oasd.de)
 */
package patterntesting.annotation.concurrent;

import java.lang.annotation.*;
import java.util.concurrent.TimeUnit;

/**
 * Instead of synchronized methods you can mark these methods as
 * "@Synchronized". The SynchronizedAspect in patterntesting.concurrent
 * will use ReentrantLock to realize it and to avoid deadlocks.
 * If you set the log level to TRACE you can get additional information
 * about the locks and waiting threads.
 * 
 * @author <a href="boehm@javatux.de">oliver</a>
 * @since 13.11.2008
 * @version $Revision: 1.1 $
 */
@Documented
@Target({ElementType.METHOD, ElementType.TYPE})
@Retention(RetentionPolicy.RUNTIME)
public @interface Synchronized {
	long timeout() default 1800L;
	TimeUnit unit() default TimeUnit.SECONDS;
}

/**
 * $Log: Synchronized.java,v $
 * Revision 1.1  2009/03/24 08:38:26  oboehm
 * concurrent package moved to patterntesting-concurrent
 *
 * $Source: /cvsroot/patterntesting/PatternTesting08/patterntesting-rt/src/main/java/patterntesting/annotation/concurrent/Synchronized.java,v $
 */
