/**
 * $Id: NullConstants.java,v 1.1 2009/06/17 19:17:33 oboehm Exp $
 *
 * Copyright (c) 2009 by Oliver Boehm
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express orimplied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 * (c)reated 13.06.2009 by oliver (ob@aosd.de)
 */
package patterntesting.runtime;

import java.io.File;

/**
 * This class contains some constants (like a NULL_STRING) as constant.
 * It can be statically imported.
 * 
 * @author <a href="boehm@javatux.de">oliver</a>
 * @since 13.06.2009
 * @version $Revision: 1.1 $
 */
public class NullConstants {
    
    /**
     * If you have a method with a list of arguments where some arguments are
     * optional you can 
     * <ul>
     *  <li>
     *      provide the method with different signatures
     *      (good idea, but not always feasible)
     *  </li>
     *  <li>
     *      admit null arguments and handle it in the methode
     *      (not a good idea because it can happen accidentally)
     *  </li>
     *  <li>
     *      use this special NULL_OBJECT object to mark an argument as optional
     *  </li>
     * </ul>
     * Unfortunately this works only for object as argument. For String as
     * argument you can use NULL_STRING.
     * 
     * @see #NULL_STRING
     */
    public static final Object NULL_OBJECT = new Object();
    
    /**
     * You need a null string and don't want to use <i>null</i>? Use
     * <i>NULL_STRING</i> and you can write code like
     * <pre>
     * if (name == NULL_STRING) ...
     * </pre
     */
    public static final String NULL_STRING = "";
    
    /**
     * You need a null file and don't want to use <i>null</i>? Use
     * <i>NULL_FILE</i> and you can write code like
     * <pre>
     * if (name == NULL_STRING) ...
     * </pre
     */
    public static final File NULL_FILE = new File(NULL_STRING);

}

/**
 * $Log: NullConstants.java,v $
 * Revision 1.1  2009/06/17 19:17:33  oboehm
 * providing now a NULL_FILE as constant
 *
 * $Source: /cvsroot/patterntesting/PatternTesting08/patterntesting-rt/src/main/java/patterntesting/runtime/NullConstants.java,v $
 */
