/**
 * $Id: ClasspathHelper.java,v 1.1 2009/08/03 06:12:37 oboehm Exp $
 *
 * Copyright (c) 2009 by Oliver Boehm
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express orimplied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 * (c)reated 27.07.2009 by oliver (ob@oasd.de)
 */

package patterntesting.runtime.util;

import java.io.File;
import java.net.*;

import org.apache.commons.lang.StringUtils;
import org.apache.commons.logging.*;

import patterntesting.runtime.annotation.ProfileMe;

/**
 * This class contains some helper classes which are used inside
 * ClasspathMonitor <b>and</b> ClasspathDigger.
 * Some of the methods were formerly placed in ClasspathMonitor but also
 * needed by ClasspathDigger. To avoid dependencies from ClasspathDigger to
 * ClasspathMonitor the common methods were moved to this class here.
 * 
 * @author oliver
 * @since 27.07.2009
 * @version $Revision: 1.1 $
 */
public class ClasspathHelper {
	
	private static final Log log = LogFactory.getLog(ClasspathHelper.class);

	/**
	 * Don't use @ProfileMe here! This method is also used when ProfileStatistic
	 * is set up!
	 * 
	 * @param path
	 *            e.g. "jar:file:/a/b/c.jar!/d/e.class
	 * @param resource
	 *            e.g. "/d/e.class"
	 * @return e.g. "jar:file:/a/b/c.jar"
	 */
	public static URI getParent(URI path, String resource) {
	    String parent = StringUtils.removeEnd(path.toString(), resource);
	    if (parent.endsWith(File.separator)) {
	        parent = parent.substring(0, (parent.length() - 1));
	    }
	    if (parent.endsWith("!")) {
	        parent = parent.substring(0, (parent.length() - 1));
	    }
	    try {
	        return new URI(parent);
	    } catch (URISyntaxException canthappen) {
	        log.error("can't extract " + resource + " from " + path,
	        		canthappen);
	        return path;
	    }
	}

	/**
	 * Gets the parent of the given class.
	 * 
	 * @param path
	 *            e.g. "jar:file:/a/b/c.jar!/d/e.class
	 * @param clazz
	 *            e.gl. "d.e.class"
	 * @return e.g. "jar:file:/a/b/c.jar"
	 */
	@ProfileMe
	public static URI getParent(URI path, Class<?> clazz) {
	    String resource = Converter.toResource(clazz);
	    return getParent(path, resource);
	}

}


/*
 * $Log: ClasspathHelper.java,v $
 * Revision 1.1  2009/08/03 06:12:37  oboehm
 * partially support of WLS classload (via getClasspathFromPackages)
 *
 * $Source: /cvsroot/patterntesting/PatternTesting08/patterntesting-rt/src/main/java/patterntesting/runtime/util/ClasspathHelper.java,v $
 */
