/**
 * $Id: MethodSignatureImpl.java,v 1.2 2009/04/09 18:30:47 oboehm Exp $
 *
 * Copyright (c) 2009 by Oliver Boehm
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express orimplied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 * (c)reated 03.04.2009 by oliver (ob@aosd.de)
 */
package patterntesting.runtime.util.reflect;

import java.lang.reflect.Method;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.impl.LogFactoryImpl;
import org.aspectj.lang.reflect.MethodSignature;

import patterntesting.runtime.annotation.UnsupportedOperation;
import patterntesting.runtime.util.Converter;

/**
 * There is a class org.aspectj.runtime.reflect.MethodSignatureImpl in
 * aspectjrt.jar. But this class is not public so we must do it ourself.
 * 
 * @see MethodSignature
 * 
 * @author <a href="boehm@javatux.de">oliver</a>
 * @since 03.04.2009
 * @version $Revision: 1.2 $
 */
public class MethodSignatureImpl implements MethodSignature {
    
    private static final Log log = LogFactoryImpl.getLog(MethodSignatureImpl.class);
    private final Method method;
    
    public MethodSignatureImpl(Method method) {
        this.method = method;
    }

    /**
     * @see org.aspectj.lang.reflect.MethodSignature#getMethod()
     */
    public Method getMethod() {
        return this.method;
    }

    /**
     * @see org.aspectj.lang.reflect.MethodSignature#getReturnType()
     */
    public Class<?> getReturnType() {
        return this.method.getReturnType();
    }

    /**
     * @see org.aspectj.lang.reflect.CodeSignature#getExceptionTypes()
     */
    public Class<?>[] getExceptionTypes() {
        return this.method.getExceptionTypes();
    }

    /**
     * @see org.aspectj.lang.reflect.CodeSignature#getParameterNames()
     */
    @UnsupportedOperation
    public String[] getParameterNames() {
        log.debug("this operation is not implemented");
        return null;
    }

    /**
     * @see org.aspectj.lang.reflect.CodeSignature#getParameterTypes()
     */
    public Class<?>[] getParameterTypes() {
        return this.method.getParameterTypes();
    }

    /**
     * @see org.aspectj.lang.Signature#getDeclaringType()
     */
    public Class<?> getDeclaringType() {
        return this.method.getDeclaringClass();
    }

    /**
     * @see org.aspectj.lang.Signature#getDeclaringTypeName()
     */
    public String getDeclaringTypeName() {
        return this.getDeclaringType().getName();
    }

    /**
     * @see org.aspectj.lang.Signature#getModifiers()
     */
    public int getModifiers() {
        return this.method.getModifiers();
    }

    /**
     * @see org.aspectj.lang.Signature#getName()
     */
    public String getName() {
        return this.method.getName();
    }

    /**
     * @see org.aspectj.lang.Signature#toLongString()
     */
    public String toLongString() {
        return this.method.toGenericString();
    }

    /**
     * @see org.aspectj.lang.Signature#toShortString()
     */
    public String toShortString() {
        return this.method.toString();
    }

    /**
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        return this.getReturnType() + " " + this.getDeclaringTypeName() + "."
                + this.getName() + "("
                + Converter.toShortString(this.getParameterTypes()) + ")";
    }
    
    

}

/**
 * $Log: MethodSignatureImpl.java,v $
 * Revision 1.2  2009/04/09 18:30:47  oboehm
 * no longer double entries (bug 2745302 fixed)
 *
 * Revision 1.1  2009/04/03 21:30:09  oboehm
 * with (Abstract)ProfileAspect it is now possible
 * to find methods/constructors which are never called
 *
 * $Source: /cvsroot/patterntesting/PatternTesting08/patterntesting-rt/src/main/java/patterntesting/runtime/util/reflect/MethodSignatureImpl.java,v $
 */
